extensions [table csv]

breed [CBDs CBD]
breed [inhabitants inh]

inhabitants-own [
  income
  household-size
  required-surface 
  current-utility
  current-surface
  current-transport-cost
  current-good
  current-rent
  travel-dist
  option-table
  self-ticker
  new-patch-pcode
  homeless-time
  best-good
  age
  ]
patches-own [
  numIhn
  pcode
  rent
  surface-amount
  available-surface
  dist
  dev-index
  r-seed
  revenue
  housing-age
  untouch
  ;temp
  sumIncome
  ]
globals[
  controlByR
  incomeList
  starting-surface
  avg-good
  view-mode
  ;min-income max-income
  die-incomeList
  avg-dev-index
;  rich-u
;  poor-u
;  middle-u
  dis-list
  t-schelling
  uiratio
  need-move
  actual-move
  a
  ]

; ;Setup procedures

to setup1
  ca
  set die-incomeList []
  set dis-list []
  set view-mode "normal"
  ;set starting-rent 10
  set starting-surface 100
  set avg-good 400
  set t-schelling 0
  setup-CBD
  setup-patches


end

to setup2
  setup-inhabitants num-of-inhabitant
  ;set min-income min [income] of inhabitants
  ;set max-income max [income] of inhabitants
  plot-graphs
  reset-ticks
end

to setup-CBD
  create-CBDs 1
  ask CBDs
  [
    set color red
    set shape "circle"
    set size 2
  ]
end

to setup-patches
  ask patches
  [
    set pcode word pxcor ":" 
    set pcode word pcode pycor 
    set rent starting-rent
    set surface-amount starting-surface
    set available-surface surface-amount
    set dist min[distance myself] of CBDs
    set r-seed random 4
    set revenue 0
    set housing-age 0
    set untouch 1
    ;temp
    set sumIncome 0
  ]
end

to setup-inhabitants [num-of-inh]
  ; if not control by R, read income from CSV, otherwise R set the incomeList
  ; read income table
  if controlByR = 0
  [
  ifelse inequality-level = "high"
    [set incomeList  csv:from-file "C:/Users/guoc/Dropbox/ABMpaper1/data/high.csv"]
    [ifelse inequality-level = "median"
      [set incomeList  csv:from-file "C:/Users/guoc/Dropbox/ABMpaper1/data/median.csv"]
      [set incomeList  csv:from-file "C:/Users/guoc/Dropbox/ABMpaper1/data/low.csv"]
    ]
    set incomeList remove-item 0 incomeList
  ]
  ask CBD 0
  [
    hatch-inhabitants num-of-inhabitant
    [
      let dr 0
      ifelse from-CBD? [set dr 3][set dr 16]
      move-to one-of patches in-radius dr with [not any? CBDs-here]
      ifelse controlByR = 0
      [
      set income first first incomeList
      ]
      [
      set income first incomeList
      ]
      set incomeList remove-item 0 incomeList  
      ;if income < 0 [set income 100]
      ;
      set required-surface 10
      
      set shape "house"
      ; A complicate min living surface, leave it out for now, all set to be 10
      ;ifelse household?
      ;[set household-size 2
      ;set required-surface (random 5 + 3) + (random 5 + 3)]
      ;[set required-surface (random 5 + 3)]
      set size 1
      ;differentiate rich ,middle and poor by color
    
      ifelse income > 1200 [set color yellow][ifelse income < 800 [set color blue][set color white]]
    
      set travel-dist [dist] of patch-here
      ;set current-surface equib-surface self patch-here
      set current-surface 0
      set current-transport-cost travel-dist * t-per-unit
      set current-good avg-good
      set current-utility utility self
    
      ;construct option-table
      set option-table table:make
    
      set self-ticker 0
      set homeless-time 0
      set age 0
    ]
  ]
    ;temp
  set a [income] of inhabitants

end

;;;;;;;;;;;;;;;;;;;;;;
;;;;;change income
;;;;;;;;;;;;;;;;;;;;;;

to ChangeIncome
  ;incomeList updated in R, ordered from high to low
  let inh-ordered-list sort-on [(- income)] inhabitants
  foreach inh-ordered-list
  [
    ask ?
    [
      set income first incomeList
      set incomeList remove-item 0 incomeList  
    ]
  ]
end


;;;;;;;;;;;;;;;;;;
;;;;;;;different view mode
;;;;;;;;;;;;;;;;;

to income-view
  ask patches [set pcolor grey]
  set view-mode "income"
  ask inhabitants
  
  [hide-turtle] 
  ask patches
  [carefully [if (any? inhabitants-here) [ set pcolor scale-color yellow (mean [income] of inhabitants-here) 500 1500]][print error-message]]
end
to rent-view
  set view-mode "rent"
  ask inhabitants  
  [hide-turtle]
  let max-rent max [rent] of patches 
  ask patches
  [carefully [set pcolor scale-color red rent 8 max-rent][print error-message]]
end
to surface-view
  ask patches [set pcolor grey]
  set view-mode "income"
  ask inhabitants
  
  [hide-turtle] 
  ask patches
  ;[carefully [if (any? inhabitants-here) [ set pcolor scale-color blue (mean [current-surface] of inhabitants-here) 10 60]][print error-message]]
  [carefully [if (any? inhabitants-here) [ set pcolor  blue ]][print error-message]]
end  

to normal-view
  set view-mode "normal"
  ask inhabitants  [show-turtle]
    ask patches with [untouch = 0]
  [
    set pcolor brown
  ]
  ask patches with [untouch = 1]
  [
    set pcolor brown
  ]
  if ticks != 0
  [ask inhabitants with [current-surface = 0] [hide-turtle]]
  
end

to number-of-renter
  set view-mode "num-renter"
  ask inhabitants  
  [hide-turtle] 
  let max-turtle max [count inhabitants-here] of patches
  ask patches
  [carefully [set pcolor scale-color green (count inhabitants-here) 0 max-turtle][print error-message]]
end

to homeless-view
  set view-mode "homeless-view"
  ask inhabitants  with [current-surface > 0]
  [hide-turtle] 
  ask inhabitants  with [current-surface = 0]
  [show-turtle] 
end

to avg-year-view
  set view-mode "homeless-view"
  ask inhabitants  with [current-surface > 0]
  [hide-turtle] 
  ask patches with [not any? CBDs-here]
  [
    let avg-year 0
    if count inhabitants-here > 0
    [
      set avg-year mean [age] of inhabitants-here
    ]
    set pcolor scale-color orange avg-year 0 50
  ]
end

to dev-index-view
  set view-mode "dev-index-view"
  ask inhabitants   [hide-turtle] 
  ask patches with [not any? CBDs-here]
  [
    set pcolor scale-color pink dev-index 0 1
  ]
  
end
;;;;;;;;;;;;;;;;;;;;;

;;runtime procedures
to go
  ;;;;;;;;;;;;;;stop condition
  ;if ticks = 50 [stop]
  ask inhabitants
  [
    update-inh current-surface
  ]
  ;uiratio
  let aa (median [income] of inhabitants - min [income] of inhabitants)
  if aa = 0 [set aa 1]
  if stress?
  [set uiratio (median [current-utility] of inhabitants - min [current-utility] of inhabitants) / aa]
  ;step 0
  ;decrease housing quality

  ;increase inhabitant by certein number each step
;  ask CBD 0
;  [
;    hatch-inhabitants immigrant
;    [
;      
;      move-to one-of patches in-radius 3 with [not any? CBDs-here]
;      set income random-normal 1000 200
;      ;set required-surface 45
;      
;      set shape "house"
;      set household-size 2
;      set required-surface (random 5 + 3) + (random 5 + 3)
;      set size 1
;      ;differentiate rich ,middle and poor by color
;    
;      ifelse income > 1200 [set color yellow][ifelse income < 800 [set color blue][set color white]]
;    
;      set travel-dist [dist] of patch-here
;      ;set current-surface equib-surface self patch-here
;      set current-surface 0
;      set current-transport-cost travel-dist * t-per-unit
;      set current-good avg-good
;      set current-utility utility self
;    
;      ;construct option-table
;      set option-table table:make
;    
;      set self-ticker 0
;      set homeless-time 0
;      set age random 50
;    ]
;  ]
;  if ticks != 0 
;  [
;    set t-schelling schelling?
;       
;  ]
;  ask inhabitants
;  [ 
;    ;have kids 10%
;    if age <= 10 and random-float 1 < birth-rate
;    [
;      set household-size household-size + 1
;      set required-surface required-surface + (random 5 + 3)
;    ]
;    if age > 20 and household-size > 2
;    [
;      ;kids move out
;      let num-out random (household-size - 2 + 1)
;      set household-size household-size - num-out 
;      set required-surface household-size * (random 5 + 3) 
;      print "ya"
;      hatch num-out 
;      [

;        set income random-normal 1000 200
;        ;set required-surface 45
;      
;        set shape "house"
;        set required-surface (random 5 + 3) + (random 5 + 3)
;        ;differentiate rich ,middle and poor by color
;    
;        ifelse income > 1200 [set color yellow][ifelse income < 800 [set color blue][set color white]]
;        
;        set travel-dist [dist] of patch-here
;        ;set current-surface equib-surface self patch-here
;        set current-surface 0
;        set current-transport-cost travel-dist * t-per-unit
;        set current-good avg-good
;        set current-utility utility self
;    
;        ;construct option-table
;        set option-table table:make
;    
;        set self-ticker 0
;        set homeless-time 0
;        set age 0
;      ]
;    ]
;    ifelse (death and age > 50)
;    [die]
;    [      print "ba"
;      update-inh current-surface]
;  ]

  set dis-list []
  ;step 1
  ;order inhabitants by income
  let inh-ordered-list sort-on [(- income)] inhabitants
  set need-move 0
  set actual-move 0
  carefully[
  foreach inh-ordered-list
  [
    ask ?
    [
      if ((([current-utility] of ? - min [current-utility] of inhabitants) / ([income] of ? + 1 - min [income] of inhabitants) ) < uiratio or ticks = 0 or not stress?)
      [
      set need-move need-move + 1
      sense-and-evaluate
      let op-table [option-table] of ?
      set best-good table-element op-table 1 4
      let mark-homeless 0
      if best-good < 0.2 * avg-good [set homeless-time homeless-time + 1 set mark-homeless 1 ]
      ;move to the 1st choice in op-table
      let new-patch-xy xytoposlist table-element op-table 1 1
      ;print new-patch-xy
      let new-patch patch first new-patch-xy last new-patch-xy
      let option-utility table-element op-table 1 2   
      let new-surface table-element op-table 1 3
      set new-patch-pcode table-element op-table 1 1
      let old-patch patch-here
      if mark-homeless = 0
      [

        move self patch-here new-patch new-surface
        set new-patch patch-here
        if old-patch != new-patch [ set self-ticker 0 set actual-move actual-move + 1]
      
      ]
      ;check if has space
      if ([current-surface] of ? = 0 and mark-homeless = 0)
      [
        set homeless-time homeless-time + 1
      ]
      if [current-surface] of ? != 0 
      [set homeless-time 0]
      if homeless-time > 3 [die-inhabitant ?]        
      
      ]
      ;tick
      
      set self-ticker self-ticker + 1 
      set age age + 1
    ]
    
  ]][ print error-message 
  ]
  ;step 2.0 update revenue of patches
  ask patches
  [
    set revenue revenue + (surface-amount - available-surface) * rent
  ]

  ;no update of surface
  if true[
  ask patches
  [
    let nb-patchset (neighbors with [not any? CBDs-here])
    let nb-av-surface sum [available-surface] of nb-patchset
    let nb-surface-amount sum [surface-amount] of nb-patchset
    let rent-index (0.3 * (nb-surface-amount - nb-av-surface) / nb-surface-amount + 0.7 * (surface-amount - available-surface) / surface-amount)
    if ( rent-index > 0.9)
    [ set rent rent * 1.1]
    if ( rent-index < 0.5)
    [ set rent rent * 0.9 ]
    if (rent < starting-rent)
    [ set rent starting-rent ]
    ;if (pxcor = 0 and pycor = 1 ) [print rent-index]
    set numIhn count inhabitants-here
  ] 
  ]
  ;;;;;;;;;;;;;;;;;;;test;;;;;;;;
  
  ;;;;;;;;;;;;;;;;;;;;;
  
  ;explort
  let record-ticks []
  ;let record-ticks (list 10 30 50 100 150 200)
  if member? ticks record-ticks
  [
    let titleword (word num-of-inhabitant "-" alpha "-t" t-per-unit "-steps-" ticks) 
    rent-view
    export-view (word "C:/Users/guoc/Documents/Netlogo/mod/Results/" "rent-view" titleword ".png")
    export-view (word "C:/Users/guoc/Documents/Netlogo/mod/Results/" "surface-view" titleword ".png")
    normal-view
    export-view (word "C:/Users/guoc/Documents/Netlogo/mod/Results/" "normal-view" titleword ".png")
    export-interface (word "C:/Users/guoc/Documents/Netlogo/mod/Results/" "interface" titleword ".png")
    export-all-plots (word  "C:/Users/guoc/Documents/Netlogo/mod/Results/" "plot" titleword ".csv") 
    export-world (word "C:/Users/guoc/Documents/Netlogo/mod/Results/" "world" titleword ".csv") 
  ]
  ;update avg-good
  if (count inhabitants > 0)
  [ set avg-good mean [current-good] of inhabitants ]
  
  
  ;view-mode
  ifelse view-mode = "normal"
  [normal-view]
  [ifelse view-mode = "income"
  [income-view]
  [ifelse view-mode = "surface"
  [surface-view]
  [ifelse view-mode = "rent"
  [rent-view]
  [ifelse view-mode = "num-renter"
  [number-of-renter]
  [
  ifelse view-mode = "homeless-view"
  [homeless-view]
  [
    if view-mode = "dev-index-view"
    [dev-index-view]
  ]
  ]
  ]
  ]
  ]
  ]
  ;update plot
  plot-graphs
  
  ;temp
  ask patches
  [
    set sumIncome (sum [income] of inhabitants-here) 
  ]
  
  tick
  let alert 0
  ask patches
  [
    if available-surface < 0
    [
      print pcode
      set alert 1
    ]
  ]
  if alert = 1 [stop]
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to test
  let f-list []
  let i 1
  while [ i < 1000]
  [set f-list fput random-normal 1000 200 f-list
    set i i + 1]
   
  print max f-list
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;functions
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to-report schelling-indicator [a-turtle]
  let cal-patches (patch-set ([patch-here] of a-turtle) ([neighbors] of [patch-here] of a-turtle))
  let total 0
  let equal-class 0
  ask cal-patches
  [
    set total total + count inhabitants-here
    set equal-class equal-class + count inhabitants-here with [color = [color] of a-turtle]
  ]
  report equal-class / total
end

to-report schelling-indicator2 [a-turtle a-patch]
  let cal-patches (patch-set a-patch ([neighbors] of a-patch ))
  let total 1
  let equal-class 1
  ask cal-patches
  [
    set total total + count inhabitants-here
    set equal-class equal-class + count inhabitants-here with [color = [color] of a-turtle]
  ]
  report equal-class / total
end

to-report cal-dev-index [a-patch]
  let di 0 
  ask a-patch
  [
    let max-sumIncome 1400 * (count inhabitants-here with [current-surface > 0])
    let income-here sum [income] of inhabitants-here with [current-surface > 0]
    let upper income-here * (surface-amount - available-surface)
    let lower max-sumIncome * surface-amount
    ifelse lower != 0 
    [set di upper / lower]
    [set di 0] 
  ]
  report di
end

to die-inhabitant [#turtle]
  ask #turtle
  [
    ask patch-here
    [ set available-surface available-surface + [current-surface] of #turtle ]
    set die-incomeList lput [income] of #turtle die-incomeList
    die
  
  ]
end

to-report equib-surface [a-turtle a-patch]
  let t-income [income] of a-turtle
  let t-dist [dist] of a-patch
  let t-rent [rent] of a-patch
  let s ( 1 - alpha ) * ( t-income - t-per-unit * t-dist ) / t-rent
  report round s
end  


to-report utility [a-turtle]
  let good [current-good] of a-turtle
  let surface [current-surface] of a-turtle
  if good < 0 [ set good 0]
  let u ( (good )  ^ alpha ) * ( (surface ) ^ ( 1 - alpha ) )
  ;if t-schelling > 0 [set u u * 2 ^ (schelling-indicator a-turtle * t-schelling)]
  ;if (not period-development) [set u u * (1 + e  ^ (- housing-age))]
  report u
end

to-report utility2 [a-turtle a-patch surface]
  ;let good [current-good] of a-turtle
  ;let surface equib-surface a-turtle a-patch
  let good income - surface * [rent] of a-patch - [dist] of a-patch * t-per-unit
  let rq-surface [required-surface] of a-turtle
  if good < 0 [ set good 0]
  if surface < 0 [set surface 0]
  let u ( (good) ^ alpha ) * ( (surface ) ^ ( 1 - alpha ) )

  report u
end

to-report equib-surface2 [t-rent t-dist t-income]
  let s ( 1 - alpha ) * ( t-income - t-per-unit * t-dist ) / t-rent
  report s
end 


to-report surface-demand [a-turtle av-surface max-u-surface]
  let s 0
  let rq-surface [required-surface] of a-turtle
  ifelse (rq-surface >= max-u-surface)
  [
    ifelse (av-surface < rq-surface)
    [ set s av-surface]
    [ set s rq-surface]
  ]
  [
    ifelse (av-surface > max-u-surface)
    [ set s max-u-surface]
    [ set s av-surface]
  ]
  if s < rq-surface [set s 0]
  report s
end

to-report good-amount[a-turtle a-patch surface]
  let t-income [income] of a-turtle
  let t-rent [rent] of a-patch
  let t-dist [dist] of a-patch
  let g t-income - t-rent * surface - t-dist * t-per-unit
  report g
end

to-report survive-surface [a-turtle a-patch]
  let t-income [income] of a-turtle
  let p-transport [dist] of a-patch * t-per-unit
  let p-rent [rent] of a-patch
  let rq-surface [required-surface] of a-turtle
  let ss (t-income - p-transport - avg-good * 0.2) / p-rent
  if (ss < rq-surface) [set ss 0]
  report round ss
end

to sense-and-evaluate
  let turtle-patch patch-here
  let candidate-patches no-patches 
  ifelse sense-radius?
  [
    let sense-radius max (list 2 (income / 300))
    set candidate-patches (patch-set patch-here n-of 10 patches in-radius sense-radius with [not any? CBDs-here])
  ]
  [
    set candidate-patches (patch-set patch-here n-of 10 patches with [not any? CBDs-here])
  ]
  let i 1  
  foreach [self] of candidate-patches
  [
    ;? is patch;self is turtle
    ;if current patch, only use already occpied surface to calculate
    let taken-surface 0
    ifelse turtle-patch = ? 
    [
      set taken-surface current-surface      
    ]
    [
      let av-surface [available-surface] of ?
      let max-u-surface equib-surface self ?    
      set taken-surface surface-demand self av-surface max-u-surface      
    ]
    let good good-amount self ? taken-surface
    if good < 0.2 * avg-good 
    [ 
      set taken-surface survive-surface self ? 
      set good 0.2 * avg-good 
    ]
    let u utility2 self ? taken-surface
    table:put option-table i ( list ([pcode] of ?) u taken-surface good ) 
    set i i + 1
  ]
  ;print sort-by [item 1 ?1 > item 1 ?2] option-table
  ;print table-element option-table 2 2
  ;print option-table
  
  set option-table evl-table option-table  
end

to-report evl-table [#table]
  let min-g 0.2 * avg-good
  let table-length table:length #table
  let i 1
  let u-list1 [] ;utlility with g > min g
  let g-list2 [] ;good with g < min g, when g < min-g, the list will ordered by g
  while [ i < table-length + 1 ]
  [
    let good table-element #table i 4
    ifelse ( good >= min-g )
    [ set u-list1 lput (table-element #table i 2) u-list1 ]
    [ set g-list2 lput (table-element #table i 4) g-list2 ]
    set i i + 1
  ]
  
  ;sort
  set u-list1 sort-by > u-list1
  set g-list2 sort-by > g-list2
  
  ;temp table
  ;first part, with g > g-min
  let t-table table:make
  let c 1
  let taken-list []
  foreach u-list1
  [
    let k 1
    
    while [ k < table-length + 1]
    [
      if (? = table-element #table k 2 and not member? k taken-list)
      [
        ;print table:get #table k
        table:put t-table c table:get #table k
        set taken-list lput k taken-list
        set k table-length + 1
       ]
      set k k + 1
    ]
    set c c + 1
  ]
  ;second part
  set taken-list []
  foreach g-list2
  [
    
    let k 1
    ;print "?"
    while [ k < table-length + 1]
    [
      if (? = table-element #table k 4 and not member? k taken-list)
      [
        ;print table:get #table k
        table:put t-table c table:get #table k
        set taken-list lput k taken-list
        set k table-length + 1
       ]
      set k k + 1
    ]
    set c c + 1
 
  ]

  report t-table
end

to-report table-element [ #table #row #col]
  report item (#col - 1) table:get #table #row
end

to-report xyposition [a-table]
  let p-list []
  let j 1
  let table-length table:length a-table
  while [ j < table-length + 1 ]
  [
    let new table-element a-table j 1
    set p-list lput new p-list
    set j j + 1 
  ]
  report p-list
end

;"x:y" -> list with x,y
to-report xytoposlist [a-string]
    let pos word a-string ":"
    let pos-list []
    while [not empty? pos]
    [
      let $x position ":" pos
      let $item substring pos 0 $x
      carefully [set $item read-from-string $item][]
      set pos-list lput $item pos-list
      set pos substring pos ($x + 1) length pos
    ]
    report pos-list
end

to-report currentlocation [a-agent]
  let pos ""
  ask a-agent
  [
    set pos word ([pxcor] of patch-here) ":"
    set pos word pos ([pycor] of patch-here)
  ]
  report pos
end



to move [a-turtle old-patch new-patch surface]
  ;check
  ifelse (surface > [available-surface] of new-patch and old-patch != new-patch)
  [ 
    print myself
    print "error"
    print surface
    print   [available-surface] of new-patch
    print new-patch
  ]
  [
    let old-u current-utility
    let new-u utility2 self new-patch surface
    let class-col [color] of self
    ;let sd 0
    ;ifelse class-col = yellow [set sd rich-u][ifelse class-col = white[set sd middle-u][set sd poor-u]]
    if (moving-discount * new-u > old-u)
    [
      ;print ((new-u - old-u) / old-u) > 0.1
      ;print sd - old-u
      let id [who] of a-turtle
      ask old-patch
      [ 
        set available-surface available-surface + [current-surface] of a-turtle
        if available-surface > surface-amount [set available-surface surface-amount]
      ]
      ask a-turtle
      [ ;print "wront"
        move-to new-patch
        ;update information
        update-inh surface
      ]
      ask new-patch
      [ set available-surface available-surface - surface]
      set dis-list lput ([dist] of old-patch - [dist] of new-patch) dis-list
      if (untouch = 1) [set untouch 0]
    ]
    
  ]

end

to update-inh [#surface]
    set current-rent [rent] of patch-here
    set travel-dist [dist] of patch-here
    set current-surface #surface
    set current-good income - current-surface * [rent] of patch-here - travel-dist * t-per-unit
    set current-utility utility self
    set current-transport-cost travel-dist * t-per-unit
end

;;;;;;;;;;;;;;;;;;;;
;;;;;ploting;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;

to plot-graphs
  set-current-plot "density-gradient" 
  clear-plot
  set-current-plot "revenue-gradient"
  clear-plot
  set-current-plot "average-surface"
  clear-plot
  set-current-plot "available-surface"
  clear-plot
  
  let distance-to-center []
  ask patches
  [set distance-to-center fput dist distance-to-center]
  set distance-to-center remove-duplicates distance-to-center
  set distance-to-center sort-by < distance-to-center
  set distance-to-center but-first distance-to-center
  
  let avg-inh[]
  foreach distance-to-center
  [
    let num-of-inh []
    let counter 0
    ask patches with [dist = ?]
    [
      set num-of-inh lput (count inhabitants-here) num-of-inh
      set counter counter + 1
    ] 
    set avg-inh lput ((sum num-of-inh) / counter) avg-inh
  ]
  set-current-plot "density-gradient"
  set-plot-pen-mode 2
  foreach distance-to-center
  [
    let item-position position ? distance-to-center
    let inh-here item item-position avg-inh
    plotxy ? inh-here
  ]
  ;;print avg-inh
  
  
  let avg-rent[]
  foreach distance-to-center
  [
    let rents []
    let counter 0
    ask patches with [dist = ?]
    [
      set rents fput (rent * (surface-amount - available-surface)) rents
      set counter counter + 1
    ] 
    set avg-rent lput ((sum rents) / counter) avg-rent
  ]
  set-current-plot "revenue-gradient"
  set-plot-pen-mode 2
  foreach distance-to-center
  [
    let item-position position ? distance-to-center
    let rent-here item item-position avg-rent
    plotxy ? rent-here
  ]
  set-current-plot "average-surface"
  set-plot-pen-mode 2
  let avg-surface[]
  foreach distance-to-center
  [
    let surface []
    let num-inh []
    ask patches with [dist = ?]
    [
      ;set surface fput (surface-amount - available-surface) surface
      set num-inh lput (count inhabitants-here with [current-surface > 0]) num-inh
      set surface lput sum [current-surface] of inhabitants-here surface
    ]     
    ifelse (sum num-inh != 0)
    [set avg-surface lput ((sum surface) / (sum num-inh)) avg-surface]
    [set avg-surface lput 0 avg-surface]
  ]
  foreach distance-to-center
  [
    let item-position position ? distance-to-center
    let surface-here item item-position avg-surface
    plotxy ? surface-here
  ]
  set-current-plot "available-surface"
  set-plot-pen-mode 2
  let av-surface []
  foreach distance-to-center
  [
    let av-surface-s []
    ask patches with [dist = ?]
    [
      set av-surface-s lput available-surface av-surface-s
    ]
    set av-surface lput sum av-surface-s av-surface
  ]
  foreach distance-to-center
  [
    let item-position position ? distance-to-center
    let av-surface-here item item-position av-surface
    plotxy ? av-surface-here
  ]
  ;print sum av-surface
  set-current-plot "hist-income"
  clear-plot
  ;set-histogram-num-bars 10
  set-plot-pen-mode 1
  let num-incomeList []
  let level (1600 - 400) / 10
  let i 1
  repeat 10
  [
    set num-incomeList lput count inhabitants with [income > 400 + (i - 1) * level and income < 400 + i * level] num-incomeList
    set i i + 1
  ]
  set-plot-pen-mode 1
  foreach num-incomeList
  [
    plot ?
  ]
   
  ;histogram [income] of inhabitants
  
  set-current-plot "hist-surface"
  clear-plot
  ;set-plot-x-range round min [income] of inhabitants round max [income] of inhabitants
  set-plot-pen-mode 1
  carefully
  [
    plot mean [current-surface] of inhabitants with [color = blue]
    plot mean [current-surface] of inhabitants with [color = white]
    plot mean [current-surface] of inhabitants with [color = yellow]
  ][print error-message]
  
  set-current-plot "hist-dist"
  clear-plot
  ;set-plot-x-range round min [income] of inhabitants round max [income] of inhabitants
  set-plot-pen-mode 1
  carefully
  [
  plot mean [travel-dist] of inhabitants with [color = blue]
  plot mean [travel-dist] of inhabitants with [color = white]
  plot mean [travel-dist] of inhabitants with [color = yellow]
  ][print error-message]
  
  set-current-plot "hist-stay"
  clear-plot
  set-plot-pen-mode 1
  carefully
  [
    plot mean [self-ticker] of inhabitants with [color = blue]
    plot mean [self-ticker] of inhabitants with [color = white]
    plot mean [self-ticker] of inhabitants with [color = yellow]
  ][print error-message]
  
  set-current-plot "stay-gradient"
  clear-plot
  set-plot-pen-mode 2
  let avg-stay[]
  foreach distance-to-center
  [
    let stay []
    let num-inh []
    ask patches with [dist = ?]
    [
      set num-inh lput (count inhabitants-here with [current-surface > 0]) num-inh
      set stay lput sum [self-ticker] of inhabitants-here with [current-surface > 0] stay
    ]     
    ifelse (sum num-inh != 0)
    [set avg-stay lput ((sum stay) / (sum num-inh)) avg-stay]
    [set avg-stay lput 0 avg-stay]
  ]
  foreach distance-to-center
  [
    let item-position position ? distance-to-center
    let stay-here item item-position avg-stay
    plotxy ? stay-here
  ]
  set-current-plot "move-dist"
  clear-plot
  set-plot-pen-mode 1
  set-histogram-num-bars 32
  histogram dis-list
  
  set-current-plot "income-utility-ratio"
  clear-plot
  set-plot-pen-mode 2
  ask inhabitants
  [
    plotxy income current-utility
  ]
  
  set-current-plot "plot 2"
  clear-plot
  set-plot-pen-mode 1
  set-histogram-num-bars 10
  histogram a
  
end
@#$#@#$#@
GRAPHICS-WINDOW
430
17
925
533
12
12
19.43
1
10
1
1
1
0
1
1
1
-12
12
-12
12
0
0
1
ticks
30.0

BUTTON
100
21
167
54
setup
setup1\nsetup2
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
176
22
239
55
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
253
22
330
55
go-once
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
111
555
311
705
density-gradient
distance to center
density
0.0
15.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

SLIDER
100
197
215
230
alpha
alpha
0.01
0.99
0.5
0.01
1
NIL
HORIZONTAL

BUTTON
1963
768
2026
801
NIL
test
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
265
114
352
147
Rent view
rent-view
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
946
418
1146
568
revenue-gradient
NIL
NIL
0.0
16.0
0.0
1000.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

BUTTON
100
115
249
148
Average income view
income-view
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1633
389
1736
422
NIL
surface-view\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
100
73
198
106
NIL
normal-view
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
225
73
353
106
NIL
number-of-renter
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
470
717
670
867
average-surface
NIL
NIL
0.0
10.0
0.0
60.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

SLIDER
101
247
210
280
t-per-unit
t-per-unit
5
50
10
1
1
NIL
HORIZONTAL

INPUTBOX
324
239
409
299
num-of-inhabitant
1000
1
0
Number

MONITOR
905
618
979
663
mean good
round avg-good
17
1
11

MONITOR
908
673
981
718
household
count inhabitants
17
1
11

PLOT
1151
105
1351
255
available-surface
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

MONITOR
898
729
951
774
avg utility
precision mean [current-utility] of inhabitants 2
17
1
11

MONITOR
987
618
1060
663
homeless
count inhabitants with [current-surface = 0]
17
1
11

MONITOR
904
783
961
828
stay >5
count inhabitants with [self-ticker > 5]
17
1
11

MONITOR
957
729
1032
774
avg-stay o30
precision mean [self-ticker] of inhabitants with [age > 30]  1
17
1
11

PLOT
341
557
541
707
hist-income
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

MONITOR
977
783
1081
828
mean die income
round mean die-incomeList
17
1
11

PLOT
111
719
271
869
hist-surface
poor  middle  rich
NIL
0.0
3.0
0.0
100.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

PLOT
291
718
451
868
hist-dist
poor  middle  rich
NIL
0.0
3.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

BUTTON
1122
680
1234
713
NIL
homeless-view
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
993
673
1076
718
total surface
sum [surface-amount] of patches - 100
17
1
11

MONITOR
983
546
1056
591
av-surface
sum [available-surface] of patches - 100
17
1
11

MONITOR
1484
585
1556
630
max.di
precision max [dev-index] of patches 2
17
1
11

MONITOR
1501
635
1567
680
avg-dev-i
precision avg-dev-index 2
17
1
11

MONITOR
1484
529
1541
574
min di
precision min [dev-index] of patches with [dev-index > 0] 2
17
1
11

SLIDER
236
197
359
230
starting-rent
starting-rent
1
30
10
1
1
NIL
HORIZONTAL

MONITOR
1072
470
1152
515
avg-surface
precision mean [current-surface] of inhabitants 1
17
1
11

MONITOR
1438
635
1495
680
med.di
precision median [dev-index] of patches 2
17
1
11

PLOT
977
107
1137
257
hist-stay
poor  middle  rich
NIL
0.0
3.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

PLOT
1306
470
1466
590
stay-gradient
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

PLOT
568
557
768
707
move-dist
NIL
NIL
-16.0
16.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

INPUTBOX
1487
743
1564
803
immigrant
0
1
0
Number

BUTTON
1830
764
1942
797
NIL
avg-year-view
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
1320
24
1416
57
schelling?
schelling?
0
1
0
0.1
1
NIL
HORIZONTAL

SLIDER
1302
93
1502
126
new-development-discount
new-development-discount
0
1
1
0.1
1
NIL
HORIZONTAL

PLOT
1287
531
1447
651
plot 1
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot count inhabitants"

SLIDER
1301
134
1473
167
moving-discount
moving-discount
0
1
0.9
0.1
1
NIL
HORIZONTAL

SLIDER
1445
497
1543
530
birth-rate
birth-rate
0
0.5
0
0.01
1
NIL
HORIZONTAL

PLOT
1704
200
1864
320
income-utility-ratio
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

PLOT
1402
652
1562
772
need/actual-move
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -11085214 true "" "plot actual-move"
"pen-1" 1.0 0 -5298144 true "" "plot need-move"

PLOT
1553
10
1713
130
utitliy/income-ratio
NIL
NIL
0.0
1.0E-13
0.0
1.0E-9
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot uiratio"

MONITOR
1028
651
1091
696
under 30
precision mean [self-ticker] of inhabitants with [age < 30]  1
17
1
11

PLOT
1285
363
1445
483
actual/need-move-ratio
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "carefully[plot (actual-move / need-move)][]"

SWITCH
1437
282
1540
315
death
death
1
1
-1000

SWITCH
1438
366
1552
399
from-CBD?
from-CBD?
1
1
-1000

SWITCH
1437
325
1555
358
household?
household?
1
1
-1000

SWITCH
281
312
384
345
stress?
stress?
0
1
-1000

SWITCH
113
313
245
346
sense-radius?
sense-radius?
1
1
-1000

BUTTON
1027
47
1144
80
NIL
dev-index-view\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
219
244
315
289
inequality-level
inequality-level
"low" "medium" "high"
2

PLOT
1193
784
1393
934
plot 2
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

TEXTBOX
37
30
77
48
Control
11
0.0
1

TEXTBOX
27
86
89
104
View option:
11
0.0
1

TEXTBOX
29
210
87
228
Parameters:
11
0.0
1

TEXTBOX
50
569
73
587
Plot
11
0.0
1

BUTTON
100
155
246
188
Average living space
surface-view
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

@#$#@#$#@
## WHAT IS IT?

a test model for urban residential mobility
That's from branches
## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.2.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment-alpha-influence" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <enumeratedValueSet variable="rent-dev-mode">
      <value value="&quot;nb&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-of-inhabitant">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="need-stay">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="surface-increase">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="t-per-unit">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alpha">
      <value value="0.4"/>
      <value value="0.1"/>
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>let outpath ""
ifelse income-dist = "exponential" 
[set outpath word "C:/Users/guoc/Documents/AAG2015/plot3/plot-exp-" word behaviorspace-run-number ".csv"]
[ifelse income-dist = "normal" 
[set outpath word "C:/Users/guoc/Documents/AAG2015/plot3/plot-nor-" word (behaviorspace-run-number - 30) ".csv"]
[set outpath word "C:/Users/guoc/Documents/AAG2015/plot3/plot-uni-" word (behaviorspace-run-number - 60) ".csv"]]
export-plot "density-gradient" outpath</final>
    <timeLimit steps="50"/>
    <metric>mean [travel-dist] of max-n-of 25 inhabitants [travel-dist]</metric>
    <enumeratedValueSet variable="income-dist">
      <value value="&quot;exponential&quot;"/>
      <value value="&quot;normal&quot;"/>
      <value value="&quot;uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-income">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="birth-rate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="starting-rent">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="schelling?">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-development-discount">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sense-radius?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="moving-discount">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-of-inhabitant">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stress?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="t-per-unit">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="household?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alpha">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="from-CBD?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrant">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="uniform" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>let outpath word "C:/Users/guoc/Documents/AAG2015/plot/plot-uni-" word behaviorspace-run-number ".csv"
export-plot "density-gradient" outpath</final>
    <timeLimit steps="50"/>
    <metric>max [travel-dist] of inhabitants</metric>
    <enumeratedValueSet variable="income-dist">
      <value value="&quot;uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="birth-rate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="starting-rent">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="schelling?">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-development-discount">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sense-radius?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="moving-discount">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-of-inhabitant">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stress?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="t-per-unit">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="household?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alpha">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="from-CBD?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrant">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="trans" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>let num (behaviorspace-run-number - (t-per-unit / 10 - 1) * 30)
let outpath word "C:/Users/guoc/Documents/AAG2015/plot/plot-trans-" word t-per-unit word "-" word num ".csv"
export-plot "density-gradient" outpath</final>
    <timeLimit steps="100"/>
    <metric>max [travel-dist] of inhabitants</metric>
    <steppedValueSet variable="t-per-unit" first="10" step="10" last="50"/>
    <enumeratedValueSet variable="birth-rate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="starting-rent">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="schelling?">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-development-discount">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sense-radius?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="moving-discount">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-of-inhabitant">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stress?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-dist">
      <value value="&quot;exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="household?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alpha">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="from-CBD?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrant">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="avg-income" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>let num (behaviorspace-run-number - ((mean-income - 500) / 10 ))
let outpath word "C:/Users/guoc/Documents/AAG2015/plot/plot-avgincome-" word mean-income word "-" word num ".csv"
export-plot "density-gradient" outpath</final>
    <timeLimit steps="50"/>
    <metric>mean [travel-dist] of max-n-of 25 inhabitants [travel-dist]</metric>
    <steppedValueSet variable="mean-income" first="500" step="100" last="1500"/>
    <enumeratedValueSet variable="new-development-discount">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="birth-rate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="starting-rent">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-of-inhabitant">
      <value value="400"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stress?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-dist">
      <value value="&quot;normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sense-radius?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alpha">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="moving-discount">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrant">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="from-CBD?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="household?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="t-per-unit">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="schelling?">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
